package handlers

import (
	"github.com/go-openapi/runtime/middleware"
	"github.com/jmoiron/sqlx"
	"github.com/rs/zerolog"
	"orus.io/orus-io/go-orusapi/database"

	"orus.io/orus-io/rednerd/models"
	"orus.io/orus-io/rednerd/restapi/operations/file_management"
)

func NewFileDeleteHandler(db *sqlx.DB) *FileDeleteHandler {
	return &FileDeleteHandler{db}
}

type FileDeleteHandler struct {
	db *sqlx.DB
}

func (h *FileDeleteHandler) Handle(
	params file_management.FileDeleteParams,
	principal *models.Principal,
) middleware.Responder {
	ctx := params.HTTPRequest.Context()
	log := zerolog.Ctx(ctx)

	var root string

	if params.Root != nil {
		root = *params.Root
	}

	perms, err := GetFileRootPerms(root, principal)
	if err != nil {
		return BadRequestError(err)
	}

	if !perms.Delete {
		return Unauthorized("")
	}

	path, err := NormalizeFilePath(params.Path)
	if err != nil {
		return NewHTTPErrorResponder(err)
	}

	tx, err := database.Begin(ctx, h.db)
	if err != nil {
		return InternalError(err, log, false)
	}
	defer tx.RollbackIfOpened(*log)

	db := database.NewSQLHelper(ctx, tx, *log)

	if err := models.DeleteFile(&db, root, path); err != nil {
		return InternalError(err, log, false)
	}

	if err := tx.Commit(); err != nil {
		return InternalError(err, log, false)
	}

	return file_management.NewFileDeleteNoContent()
}
