package handlers_test

import (
	"testing"

	"github.com/stretchr/testify/assert"

	"orus.io/orus-io/rednerd/restapi/handlers"
)

func TestNormalizeFilePath(t *testing.T) {
	for _, tt := range []struct {
		name     string
		value    string
		expected string
		err      string
	}{
		{"root", "/", "/", ""},
		{"need_cleaning", "/.//some//dir", "/some/dir", ""},
		{"missing_leading_slash", "some/dir", "/some/dir", ""},
		{"forbidden_segment", "/some/../../../dir", "", "BadRequest400: Bad Request: '..' is not allowed in file paths"},
	} {
		t.Run(tt.name, func(t *testing.T) {
			actual, err := handlers.NormalizeFilePath(tt.value)
			assert.Equal(t, tt.expected, actual)

			if tt.err != "" {
				assert.EqualError(t, err, tt.err)
			} else {
				assert.NoError(t, err)
			}
		})
	}
}
