package handlers

import (
	"fmt"
	"io"
	"net/http"

	"github.com/go-openapi/runtime"
)

/* FileResponse.
 */
type FileResponse struct {
	Filename string
	Mimetype string
	ETag     string
	Body     io.ReadCloser
}

// NewFileResponse creates AccountTemplatePreviewOK with default headers values.
func NewFileResponse() *FileResponse {
	return &FileResponse{}
}

// WithFilename set the response Filename.
func (o *FileResponse) WithFilename(filename string) *FileResponse {
	o.Filename = filename

	return o
}

// WithMimetype set the response Mimetype.
func (o *FileResponse) WithMimetype(mimetype string) *FileResponse {
	o.Mimetype = mimetype

	return o
}

// WithETag set the response ETag header.
func (o *FileResponse) WithETag(etag string) *FileResponse {
	o.ETag = etag

	return o
}

// SetETag set the response ETag header.
func (o *FileResponse) SetETag(etag string) {
	o.ETag = etag
}

// WithDocument set the document to return.
func (o *FileResponse) WithBody(body io.ReadCloser) *FileResponse {
	o.Body = body

	return o
}

// WriteResponse to the client.
func (o *FileResponse) WriteResponse(rw http.ResponseWriter, producer runtime.Producer) {
	// response header Content-Type
	rw.Header().Set("Content-Type", o.Mimetype)
	rw.Header().Set("Content-Disposition", fmt.Sprintf("attachment; filename=\"%s\"", o.Filename))

	if o.ETag != "" {
		rw.Header().Set("ETag", o.ETag)
	}

	rw.WriteHeader(http.StatusOK)

	if _, err := io.Copy(rw, o.Body); err != nil {
		panic(err)
	}

	if err := o.Body.Close(); err != nil {
		panic(err)
	}
}
